@@ -11,9 +11,13 @@
 #define MPITIMPL_H_INCLUDED
 
 #include "mpi.h"
-#include "mpiutil.h"
-#include "mpiu_utarray.h"
-#include "mpiu_uthash.h"
+#include "mpir_strerror.h"
+#include "mpir_type_defs.h"
+#include "mpir_assert.h"
+#include "mpir_pointers.h"
+#include "utarray.h"
+#include "uthash.h"
+#include "mpir_objects.h"
 
 #ifdef HAVE_ERROR_CHECKING
 typedef enum {
@@ -28,7 +32,7 @@ typedef enum {
 /* MPI_T enum
  */
 typedef struct enum_item_s {
-    const char* name;
+    const char *name;
     int value;
 } enum_item_t;
 
@@ -53,8 +57,8 @@ typedef struct {
 /* Hash names to indices in a table */
 typedef struct {
     const char *name;
-    int idx;
-    UT_hash_handle hh;  /* Makes this structure hashable */
+    unsigned idx;
+    UT_hash_handle hh;          /* Makes this structure hashable */
 } name2index_hash_t;
 
 /* MPI_T control variable (cvar)
@@ -71,7 +75,7 @@ typedef union MPIR_T_cvar_value_s {
     unsigned ul;
     unsigned ull;
     MPI_Count c;
-    char* str;
+    const char *str;
     double f;
     MPIR_T_cvar_range_value_t range;
 } MPIR_T_cvar_value_t;
@@ -92,11 +96,11 @@ typedef struct cvar_table_entry_s {
     /* cvar data type */
     MPI_Datatype datatype;
 
-     /* Num. of elements of the cvar. May be ignored when get_count != NULL */
+    /* Num. of elements of the cvar. May be ignored when get_count != NULL */
     int count;
 
     /* Properties of the cvar */
-    MPI_T_enum  enumtype;
+    MPI_T_enum enumtype;
     MPIR_T_verbosity_t verbosity;
     MPIR_T_bind_t bind;
     MPIR_T_scope_t scope;
@@ -119,7 +123,7 @@ typedef struct MPIR_T_cvar_handle_s {
     MPIR_T_object_kind kind;
 #endif
 
-     /* Address and count of the cvar. Set at handle allocation time */
+    /* Address and count of the cvar. Set at handle allocation time */
     void *addr;
     int count;
 
@@ -128,12 +132,11 @@ typedef struct MPIR_T_cvar_handle_s {
     MPIR_T_scope_t scope;
 } MPIR_T_cvar_handle_t;
 
-void MPIR_T_CVAR_REGISTER_impl(
-    MPI_Datatype dtype, const char* name, const void *addr, int count,
-    MPIR_T_enum_t *etype, MPIR_T_verbosity_t verb, MPIR_T_bind_t bind,
-    MPIR_T_scope_t scope,MPIR_T_cvar_get_addr_cb get_addr,
-    MPIR_T_cvar_get_count_cb get_count, MPIR_T_cvar_value_t defaultval,
-    const char *cat, const char * desc);
+void MPIR_T_CVAR_REGISTER_impl(MPI_Datatype dtype, const char *name, const void *addr, int count,
+                               MPIR_T_enum_t * etype, MPIR_T_verbosity_t verb, MPIR_T_bind_t bind,
+                               MPIR_T_scope_t scope, MPIR_T_cvar_get_addr_cb get_addr,
+                               MPIR_T_cvar_get_count_cb get_count, MPIR_T_cvar_value_t defaultval,
+                               const char *cat, const char *desc);
 
 /* MPI_T performance variable (pvar)
  */
@@ -183,13 +186,13 @@ typedef struct {
     /* pvar data type */
     MPI_Datatype datatype;
 
-     /* Num. of elements of the pvar */
+    /* Num. of elements of the pvar */
     int count;
 
     /* Properties of the pvar */
     MPIR_T_pvar_class_t varclass;
     MPIR_T_verbosity_t verbosity;
-    MPIR_T_enum_t  *enumtype;
+    MPIR_T_enum_t *enumtype;
     MPIR_T_bind_t bind;
 
     /* Basic flags of the pvar */
@@ -215,11 +218,6 @@ typedef struct {
             action_; \
         #endif \
     } while (0)
-
-#define PVAR_GATED_DECL(MODULE, declaration_) \
-    #ifdef ENABLE_PVAR_##MODULE \
-        declaration_; \
-    #endif
 */
 
 /* ENABLE_PVAR_##MODULE must be defined by configure script either to 0 or 1 */
@@ -230,11 +228,6 @@ typedef struct {
         } \
     } while (0)
 
-/* The declaration is not gated. But any compiler should optimize it away if
- * there are no references to the declared varaible */
-#define PVAR_GATED_DECL(MODULE_, declaration_) \
-    declaration_
-
 /* For some classes of pvars, internally we can not represent them
  * in basic data types. So come the following typedefs.
  */
@@ -350,11 +343,13 @@ typedef struct MPIR_T_pvar_session_s {
     MPIR_T_pvar_handle_t *hlist;
 } MPIR_T_pvar_session_t;
 
-extern void MPIR_T_PVAR_REGISTER_impl(
-    int varclass, MPI_Datatype dtype, const char* name, void *addr, int count,
-    MPIR_T_enum_t *etype, int verb, int bind, int flags,
-    MPIR_T_pvar_get_value_cb get_value, MPIR_T_pvar_get_count_cb get_count,
-    const char * cat, const char * desc);
+extern void MPIR_T_PVAR_REGISTER_impl(MPIR_T_pvar_class_t varclass, MPI_Datatype dtype,
+                                      const char *name, void *addr, int count,
+                                      MPIR_T_enum_t * etype, MPIR_T_verbosity_t verb,
+                                      MPIR_T_bind_t bind, int flags,
+                                      MPIR_T_pvar_get_value_cb get_value,
+                                      MPIR_T_pvar_get_count_cb get_count, const char *cat,
+                                      const char *desc);
 
 /* For static pvars (i.e., pvars with static storage), we embed their class name
  * into their variable name, so that users can declare pvars with the same name
@@ -365,14 +360,6 @@ extern void MPIR_T_PVAR_REGISTER_impl(
 /* MPI_T_PVAR_CLASS_STATE (continuous only)
  */
 
-/* Declaration -- static pvar */
-#define MPIR_T_PVAR_INT_STATE_DECL_impl(name_) \
-    int PVAR_STATE_##name_;
-#define MPIR_T_PVAR_INT_STATE_DECL_STATIC_impl(name_) \
-    static int PVAR_STATE_##name_;
-#define MPIR_T_PVAR_INT_STATE_DECL_EXTERN_impl(name_) \
-    extern int PVAR_STATE_##name_;
-
 /* Interfaces through pointer or name */
 #define MPIR_T_PVAR_STATE_SET_VAR_impl(ptr_, val_) \
     do { *(ptr_) = (val_); } while (0)
@@ -390,12 +377,12 @@ extern void MPIR_T_PVAR_REGISTER_impl(
     do { \
         void *addr_; \
         /* Allowable datatypes only */ \
-        MPIU_Assert((dtype_) == MPI_INT); \
+        MPIR_Assert((dtype_) == MPI_INT); \
         /* Double check if dtype_ and name_ match */ \
-        MPIU_Assert(sizeof(PVAR_STATE_##name_) == MPID_Datatype_get_basic_size(dtype_)); \
-        MPIU_Assert((flags_) & MPIR_T_PVAR_FLAG_CONTINUOUS); \
+        MPIR_Assert(sizeof(PVAR_STATE_##name_) == MPIR_Datatype_get_basic_size(dtype_)); \
+        MPIR_Assert((flags_) & MPIR_T_PVAR_FLAG_CONTINUOUS); \
         /* State pvars should be describled further by an enum */ \
-        MPIU_Assert((etype_) != MPI_T_ENUM_NULL); \
+        MPIR_Assert((etype_) != MPI_T_ENUM_NULL); \
         PVAR_STATE_##name_ = (initval_); \
         addr_ = &PVAR_STATE_##name_; \
         MPIR_T_PVAR_REGISTER_impl(MPI_T_PVAR_CLASS_STATE, dtype_, #name_, \
@@ -407,10 +394,10 @@ extern void MPIR_T_PVAR_REGISTER_impl(
             etype_, verb_, bind_, flags_, get_value_, get_count_, cat_, desc_) \
     do { \
         /* Allowable datatypes */ \
-        MPIU_Assert((dtype_) == MPI_INT); \
-        MPIU_Assert((flags_) & MPIR_T_PVAR_FLAG_CONTINUOUS); \
-        MPIU_Assert((etype_) != MPI_T_ENUM_NULL); \
-        MPIU_Assert((addr_) != NULL || (get_value_) != NULL); \
+        MPIR_Assert((dtype_) == MPI_INT); \
+        MPIR_Assert((flags_) & MPIR_T_PVAR_FLAG_CONTINUOUS); \
+        MPIR_Assert((etype_) != MPI_T_ENUM_NULL); \
+        MPIR_Assert((addr_) != NULL || (get_value_) != NULL); \
         MPIR_T_PVAR_REGISTER_impl(MPI_T_PVAR_CLASS_STATE, dtype_, #name_, \
             addr_, count_, etype_, verb_, bind_, flags_, get_value_, cat_, desc_); \
     } while (0)
@@ -419,34 +406,6 @@ extern void MPIR_T_PVAR_REGISTER_impl(
 /* MPI_T_PVAR_CLASS_LEVEL (continuous only)
  */
 
-/* Declaration -- static pvar */
-#define MPIR_T_PVAR_UINT_LEVEL_DECL_impl(name_) \
-    unsigned int PVAR_LEVEL_##name_;
-#define MPIR_T_PVAR_ULONG_LEVEL_DECL_impl(name_) \
-    unsigned long PVAR_LEVEL_##name_;
-#define MPIR_T_PVAR_ULONG2_LEVEL_DECL_impl(name_) \
-    unsigned long long PVAR_LEVEL_##name_;
-#define MPIR_T_PVAR_DOUBLE_LEVEL_DECL_impl(name_) \
-    double PVAR_LEVEL_##name_;
-
-#define MPIR_T_PVAR_UINT_LEVEL_DECL_STATIC_impl(name_) \
-    static unsigned PVAR_LEVEL_##name_;
-#define MPIR_T_PVAR_ULONG_LEVEL_DECL_STATIC_impl(name_) \
-    static unsigned long PVAR_LEVEL_##name_;
-#define MPIR_T_PVAR_ULONG2_LEVEL_DECL_STATIC_impl(name_) \
-    static unsigned long long PVAR_LEVEL_##name_;
-#define MPIR_T_PVAR_DOUBLE_LEVEL_DECL_STATIC_impl(name_) \
-    static double PVAR_LEVEL_##name_;
-
-#define MPIR_T_PVAR_UINT_LEVEL_DECL_EXTERN_impl(name_) \
-    extern unsigned PVAR_LEVEL_##name_;
-#define MPIR_T_PVAR_ULONG_LEVEL_DECL_EXTERN_impl(name_) \
-    extern unsigned long PVAR_LEVEL_##name_;
-#define MPIR_T_PVAR_ULONG2_LEVEL_DECL_EXTERN_impl(name_) \
-    extern unsigned long long PVAR_LEVEL_##name_;
-#define MPIR_T_PVAR_DOUBLE_LEVEL_DECL_EXTERN_impl(name_) \
-    extern double PVAR_LEVEL_##name_;
-
 /* Interfaces through pointer or name */
 #define MPIR_T_PVAR_LEVEL_SET_VAR_impl(ptr_, val_) \
     do { *(ptr_) = (val_); } while (0)
@@ -472,11 +431,11 @@ extern void MPIR_T_PVAR_REGISTER_impl(
     do { \
         void *addr_; \
         /* Allowable datatypes only */ \
-        MPIU_Assert((dtype_) == MPI_UNSIGNED || (dtype_) == MPI_UNSIGNED_LONG || \
+        MPIR_Assert((dtype_) == MPI_UNSIGNED || (dtype_) == MPI_UNSIGNED_LONG || \
                     (dtype_) == MPI_UNSIGNED_LONG_LONG || (dtype_) == MPI_DOUBLE); \
         /* Double check if dtype_ and name_ match */ \
-        MPIU_Assert(sizeof(PVAR_LEVEL_##name_) == MPID_Datatype_get_basic_size(dtype_)); \
-        MPIU_Assert((flags_) & MPIR_T_PVAR_FLAG_CONTINUOUS); \
+        MPIR_Assert(sizeof(PVAR_LEVEL_##name_) == MPIR_Datatype_get_basic_size(dtype_)); \
+        MPIR_Assert((flags_) & MPIR_T_PVAR_FLAG_CONTINUOUS); \
         PVAR_LEVEL_##name_ = (initval_); \
         addr_ = &PVAR_LEVEL_##name_; \
         MPIR_T_PVAR_REGISTER_impl(MPI_T_PVAR_CLASS_LEVEL, dtype_, #name_, \
@@ -488,10 +447,10 @@ extern void MPIR_T_PVAR_REGISTER_impl(
             addr_, count_, verb_, bind_, flags_, get_value_, get_count, cat_, desc_) \
     do { \
         /* Allowable datatypes */ \
-        MPIU_Assert((dtype_) == MPI_UNSIGNED || (dtype_) == MPI_UNSIGNED_LONG || \
+        MPIR_Assert((dtype_) == MPI_UNSIGNED || (dtype_) == MPI_UNSIGNED_LONG || \
                     (dtype_) == MPI_UNSIGNED_LONG_LONG || (dtype_) == MPI_DOUBLE); \
-        MPIU_Assert((flags_) & MPIR_T_PVAR_FLAG_CONTINUOUS); \
-        MPIU_Assert((addr_) != NULL || (get_value_) != NULL); \
+        MPIR_Assert((flags_) & MPIR_T_PVAR_FLAG_CONTINUOUS); \
+        MPIR_Assert((addr_) != NULL || (get_value_) != NULL); \
         MPIR_T_PVAR_REGISTER_impl(MPI_T_PVAR_CLASS_LEVEL, dtype_, #name_, \
             addr_, count_, MPI_T_ENUM_NULL, verb_, bind_, flags_, get_value_, \
             get_count, cat_, desc_); \
@@ -501,34 +460,6 @@ extern void MPIR_T_PVAR_REGISTER_impl(
 /* MPI_T_PVAR_CLASS_SIZE (continuous only)
  */
 
-/* Declaration -- static pvar */
-#define MPIR_T_PVAR_UINT_SIZE_DECL_impl(name_) \
-    unsigned PVAR_SIZE_##name_;
-#define MPIR_T_PVAR_ULONG_SIZE_DECL_impl(name_) \
-    unsigned long PVAR_SIZE_##name_;
-#define MPIR_T_PVAR_ULONG2_SIZE_DECL_impl(name_) \
-    unsigned long long PVAR_SIZE_##name_;
-#define MPIR_T_PVAR_DOUBLE_SIZE_DECL_impl(name_) \
-    double PVAR_SIZE_##name_;
-
-#define MPIR_T_PVAR_UINT_SIZE_DECL_STATIC_impl(name_) \
-    static unsigned PVAR_SIZE_##name_;
-#define MPIR_T_PVAR_ULONG_SIZE_DECL_STATIC_impl(name_) \
-    static unsigned long PVAR_SIZE_##name_;
-#define MPIR_T_PVAR_ULONG2_SIZE_DECL_STATIC_impl(name_) \
-    static unsigned long long PVAR_SIZE_##name_;
-#define MPIR_T_PVAR_DOUBLE_SIZE_DECL_STATIC_impl(name_) \
-    static double PVAR_SIZE_##name_;
-
-#define MPIR_T_PVAR_UINT_SIZE_DECL_EXTERN_impl(name_) \
-    extern unsigned PVAR_SIZE_##name_;
-#define MPIR_T_PVAR_ULONG_SIZE_DECL_EXTERN_impl(name_) \
-    extern unsigned long PVAR_SIZE_##name_;
-#define MPIR_T_PVAR_ULONG2_SIZE_DECL_EXTERN_impl(name_) \
-    extern unsigned long long PVAR_SIZE_##name_;
-#define MPIR_T_PVAR_DOUBLE_SIZE_DECL_EXTERN_impl(name_) \
-    extern double PVAR_SIZE_##name_;
-
 /* Interfaces through pointer or name */
 #define MPIR_T_PVAR_SIZE_SET_VAR_impl(ptr_, val_) \
     do { *(ptr_) = (val_); } while (0)
@@ -546,11 +477,11 @@ extern void MPIR_T_PVAR_REGISTER_impl(
     do { \
         void *addr_; \
         /* Allowable datatypes only */ \
-        MPIU_Assert((dtype_) == MPI_UNSIGNED || (dtype_) == MPI_UNSIGNED_LONG || \
+        MPIR_Assert((dtype_) == MPI_UNSIGNED || (dtype_) == MPI_UNSIGNED_LONG || \
                     (dtype_) == MPI_UNSIGNED_LONG_LONG || (dtype_) == MPI_DOUBLE); \
         /* Double check if dtype_ and name_ match */ \
-        MPIU_Assert(sizeof(PVAR_SIZE_##name_) == MPID_Datatype_get_basic_size(dtype_)); \
-        MPIU_Assert((flags_) & MPIR_T_PVAR_FLAG_CONTINUOUS); \
+        MPIR_Assert(sizeof(PVAR_SIZE_##name_) == MPIR_Datatype_get_basic_size(dtype_)); \
+        MPIR_Assert((flags_) & MPIR_T_PVAR_FLAG_CONTINUOUS); \
         PVAR_SIZE_##name_ = (initval_); \
         addr_ = &PVAR_SIZE_##name_; \
         MPIR_T_PVAR_REGISTER_impl(MPI_T_PVAR_CLASS_SIZE, dtype_, #name_, \
@@ -562,10 +493,10 @@ extern void MPIR_T_PVAR_REGISTER_impl(
             addr_, count_, verb_, bind_, flags_, get_value_, get_count_, cat_, desc_) \
     do { \
         /* Allowable datatypes */ \
-        MPIU_Assert((dtype_) == MPI_UNSIGNED || (dtype_) == MPI_UNSIGNED_LONG || \
+        MPIR_Assert((dtype_) == MPI_UNSIGNED || (dtype_) == MPI_UNSIGNED_LONG || \
                     (dtype_) == MPI_UNSIGNED_LONG_LONG || (dtype_) == MPI_DOUBLE); \
-        MPIU_Assert((flags_) & MPIR_T_PVAR_FLAG_CONTINUOUS); \
-        MPIU_Assert((addr_) != NULL || (get_value_) != NULL); \
+        MPIR_Assert((flags_) & MPIR_T_PVAR_FLAG_CONTINUOUS); \
+        MPIR_Assert((addr_) != NULL || (get_value_) != NULL); \
         MPIR_T_PVAR_REGISTER_impl(MPI_T_PVAR_CLASS_SIZE, dtype_, #name_, \
             addr_, count_, MPI_T_ENUM_NULL, verb_, bind_, flags_, get_value_, \
             get_count_, cat_, desc_); \
@@ -575,20 +506,10 @@ extern void MPIR_T_PVAR_REGISTER_impl(
 /* MPI_T_PVAR_CLASS_PERCENTAGE (continuous only)
  */
 
-/* Declaration -- static pvar */
-#define MPIR_T_PVAR_DOUBLE_PERCENTAGE_DECL_impl(name_) \
-    double PVAR_PERCENTAGE_##name_;
-
-#define MPIR_T_PVAR_DOUBLE_PERCENTAGE_DECL_STATIC_impl(name_) \
-    static double PVAR_PERCENTAGE_##name_;
-
-#define MPIR_T_PVAR_DOUBLE_PERCENTAGE_DECL_EXTERN_impl(name_) \
-    extern double PVAR_PERCENTAGE_##name_;
-
 /* Interfaces through pointer or name */
 #define MPIR_T_PVAR_PERCENTAGE_SET_VAR_impl(ptr_, val_) \
     do { \
-        MPIU_Assert(0.0 <= (val_) && (val_) <= 1.0); \
+        MPIR_Assert(0.0 <= (val_) && (val_) <= 1.0); \
         *(ptr_) = (val_); \
     } while (0)
 #define MPIR_T_PVAR_PERCENTAGE_GET_VAR_impl(ptr_) \
@@ -605,10 +526,10 @@ extern void MPIR_T_PVAR_REGISTER_impl(
     do { \
         void *addr_; \
         /* Allowable datatypes only */ \
-        MPIU_Assert((dtype_) == MPI_DOUBLE); \
+        MPIR_Assert((dtype_) == MPI_DOUBLE); \
         /* Double check if dtype_ and name_ match */ \
-        MPIU_Assert(sizeof(PVAR_PERCENTAGE_##name_) == MPID_Datatype_get_basic_size(dtype_)); \
-        MPIU_Assert((flags_) & MPIR_T_PVAR_FLAG_CONTINUOUS); \
+        MPIR_Assert(sizeof(PVAR_PERCENTAGE_##name_) == MPIR_Datatype_get_basic_size(dtype_)); \
+        MPIR_Assert((flags_) & MPIR_T_PVAR_FLAG_CONTINUOUS); \
         addr_ = &PVAR_PERCENTAGE_##name_; \
         PVAR_PERCENTAGE_##name_ = (initval_); \
         MPIR_T_PVAR_REGISTER_impl(MPI_T_PVAR_CLASS_PERCENTAGE, dtype_, #name_, \
@@ -620,9 +541,9 @@ extern void MPIR_T_PVAR_REGISTER_impl(
             addr_, count_, verb_, bind_, flags_, get_value_, get_count_, cat_, desc_) \
     do { \
         /* Allowable datatypes */ \
-        MPIU_Assert((dtype_) == MPI_DOUBLE); \
-        MPIU_Assert((flags_) & MPIR_T_PVAR_FLAG_CONTINUOUS); \
-        MPIU_Assert((addr_) != NULL || (get_value_) != NULL); \
+        MPIR_Assert((dtype_) == MPI_DOUBLE); \
+        MPIR_Assert((flags_) & MPIR_T_PVAR_FLAG_CONTINUOUS); \
+        MPIR_Assert((addr_) != NULL || (get_value_) != NULL); \
         MPIR_T_PVAR_REGISTER_impl(MPI_T_PVAR_CLASS_PERCENTAGE, dtype_, #name_, \
             addr_, count_, MPI_T_ENUM_NULL, verb_, bind_, flags_, get_value_, \
             get_count_, cat_, desc_); \
@@ -632,28 +553,6 @@ extern void MPIR_T_PVAR_REGISTER_impl(
 /* MPI_T_PVAR_CLASS_COUNTER (continuous or not)
  */
 
-/* Declaration -- static pvar */
-#define MPIR_T_PVAR_UINT_COUNTER_DECL_impl(name_) \
-    unsigned PVAR_COUNTER_##name_;
-#define MPIR_T_PVAR_ULONG_COUNTER_DECL_impl(name_) \
-    unsigned long PVAR_COUNTER_##name_;
-#define MPIR_T_PVAR_ULONG2_COUNTER_DECL_impl(name_) \
-    unsigned long long PVAR_COUNTER_##name_;
-
-#define MPIR_T_PVAR_UINT_COUNTER_DECL_STATIC_impl(name_) \
-    static unsigned PVAR_COUNTER_##name_;
-#define MPIR_T_PVAR_ULONG_COUNTER_DECL_STATIC_impl(name_) \
-    static unsigned long PVAR_COUNTER_##name_;
-#define MPIR_T_PVAR_ULONG2_COUNTER_DECL_STATIC_impl(name_) \
-    static unsigned long long PVAR_COUNTER_##name_;
-
-#define MPIR_T_PVAR_UINT_COUNTER_DECL_EXTERN_impl(name_) \
-    extern unsigned PVAR_COUNTER_##name_;
-#define MPIR_T_PVAR_ULONG_COUNTER_DECL_EXTERN_impl(name_) \
-    extern unsigned long PVAR_COUNTER_##name_;
-#define MPIR_T_PVAR_ULONG2_COUNTER_DECL_EXTERN_impl(name_) \
-    extern unsigned long long PVAR_COUNTER_##name_;
-
 /* Interfaces through pointer or name */
 #define MPIR_T_PVAR_COUNTER_INIT_VAR_impl(ptr_) \
     do { *(ptr_) = 0; } while (0)
@@ -678,10 +577,10 @@ extern void MPIR_T_PVAR_REGISTER_impl(
     do { \
         void *addr_; \
         /* Allowable datatypes only */ \
-        MPIU_Assert((dtype_) == MPI_UNSIGNED || (dtype_) == MPI_UNSIGNED_LONG || \
+        MPIR_Assert((dtype_) == MPI_UNSIGNED || (dtype_) == MPI_UNSIGNED_LONG || \
                     (dtype_) == MPI_UNSIGNED_LONG_LONG); \
         /* Double check if dtype_ and name_ match*/ \
-        MPIU_Assert(sizeof(PVAR_COUNTER_##name_) == MPID_Datatype_get_basic_size(dtype_)); \
+        MPIR_Assert(sizeof(PVAR_COUNTER_##name_) == MPIR_Datatype_get_basic_size(dtype_)); \
         PVAR_COUNTER_##name_ = 0; \
         addr_ = &PVAR_COUNTER_##name_; \
         MPIR_T_PVAR_REGISTER_impl(MPI_T_PVAR_CLASS_COUNTER, dtype_, #name_, \
@@ -693,36 +592,14 @@ extern void MPIR_T_PVAR_REGISTER_impl(
             addr_, count_, verb_, bind_, flags_, get_value_, get_count_, cat_, desc_) \
     do { \
         /* Allowable datatypes */ \
-        MPIU_Assert((dtype_) == MPI_UNSIGNED || (dtype_) == MPI_UNSIGNED_LONG || \
+        MPIR_Assert((dtype_) == MPI_UNSIGNED || (dtype_) == MPI_UNSIGNED_LONG || \
                     (dtype_) == MPI_UNSIGNED_LONG_LONG); \
-        MPIU_Assert((addr_) != NULL || (get_value_) != NULL); \
+        MPIR_Assert((addr_) != NULL || (get_value_) != NULL); \
         MPIR_T_PVAR_REGISTER_impl(MPI_T_PVAR_CLASS_COUNTER, dtype_, #name_, \
             addr_, count_, MPI_T_ENUM_NULL, verb_, bind_, flags_, get_value_, \
             get_count_, cat_, desc_); \
     } while (0)
 
-/* Declaration of a counter array -- static pvar */
-#define MPIR_T_PVAR_UINT_COUNTER_ARRAY_DECL_impl(name_, len_) \
-    unsigned PVAR_COUNTER_##name_[len_];
-#define MPIR_T_PVAR_ULONG_COUNTER_ARRAY_DECL_impl(name_, len_) \
-    unsigned long PVAR_COUNTER_##name_[len_];
-#define MPIR_T_PVAR_ULONG2_COUNTER_ARRAY_DECL_impl(name_, len_) \
-    unsigned long long PVAR_COUNTER_##name_[len_];
-
-#define MPIR_T_PVAR_UINT_COUNTER_ARRAY_DECL_STATIC_impl(name_, len_) \
-    static unsigned PVAR_COUNTER_##name_[len_];
-#define MPIR_T_PVAR_ULONG_COUNTER_ARRAY_DECL_STATIC_impl(name_, len_) \
-    static unsigned long PVAR_COUNTER_##name_[len_];
-#define MPIR_T_PVAR_ULONG2_COUNTER_ARRAY_DECL_STATIC_impl(name_, len_) \
-    static unsigned long long PVAR_COUNTER_##name_[len_];
-
-#define MPIR_T_PVAR_UINT_COUNTER_ARRAY_DECL_EXTERN_impl(name_, len_) \
-    extern unsigned PVAR_COUNTER_##name_[len_];
-#define MPIR_T_PVAR_ULONG_COUNTER_ARRAY_DECL_EXTERN_impl(name_, len_) \
-    extern unsigned long PVAR_COUNTER_##name_[len_];
-#define MPIR_T_PVAR_ULONG2_COUNTER_ARRAY_DECL_EXTERN_impl(name_, len_) \
-    extern unsigned long long PVAR_COUNTER_##name_[len_];
-
 /* Interfaces through pointer or name */
 #define MPIR_T_PVAR_COUNTER_ARRAY_INIT_VAR_impl(ptr_, count_) \
     do { \
@@ -754,10 +631,10 @@ extern void MPIR_T_PVAR_REGISTER_impl(
         void *addr_; \
         int count_;  \
         /* Allowable datatypes only */ \
-        MPIU_Assert((dtype_) == MPI_UNSIGNED || (dtype_) == MPI_UNSIGNED_LONG || \
+        MPIR_Assert((dtype_) == MPI_UNSIGNED || (dtype_) == MPI_UNSIGNED_LONG || \
                     (dtype_) == MPI_UNSIGNED_LONG_LONG); \
         /* Double check if dtype_ and name_ match */ \
-        MPIU_Assert(sizeof(PVAR_COUNTER_##name_[0]) == MPID_Datatype_get_basic_size(dtype_)); \
+        MPIR_Assert(sizeof(PVAR_COUNTER_##name_[0]) == MPIR_Datatype_get_basic_size(dtype_)); \
         addr_ = PVAR_COUNTER_##name_; \
         MPIR_T_PVAR_COUNTER_ARRAY_INIT_impl(name_); \
         count_ = sizeof(PVAR_COUNTER_##name_)/sizeof(mpit_pvar_##name_[0]); \
@@ -770,34 +647,6 @@ extern void MPIR_T_PVAR_REGISTER_impl(
 /* MPI_T_PVAR_CLASS_AGGREGATE (continuous or not)
  */
 
-/* Declaration -- static aggregate */
-#define MPIR_T_PVAR_UINT_AGGREGATE_DECL_impl(name_) \
-    unsigned PVAR_AGGREGATE_##name_;
-#define MPIR_T_PVAR_ULONG_AGGREGATE_DECL_impl(name_) \
-    unsigned long PVAR_AGGREGATE_##name_;
-#define MPIR_T_PVAR_ULONG2_AGGREGATE_DECL_impl(name_) \
-    unsigned long long PVAR_AGGREGATE_##name_;
-#define MPIR_T_PVAR_DOUBLE_AGGREGATE_DECL_impl(name_) \
-    double PVAR_AGGREGATE_##name_;
-
-#define MPIR_T_PVAR_UINT_AGGREGATE_DECL_STATIC_impl(name_) \
-    static unsigned PVAR_AGGREGATE_##name_;
-#define MPIR_T_PVAR_ULONG_AGGREGATE_DECL_STATIC_impl(name_) \
-    static unsigned long PVAR_AGGREGATE_##name_;
-#define MPIR_T_PVAR_ULONG2_AGGREGATE_DECL_STATIC_impl(name_) \
-    static unsigned long long PVAR_AGGREGATE_##name_;
-#define MPIR_T_PVAR_DOUBLE_AGGREGATE_DECL_STATIC_impl(name_) \
-    static double PVAR_AGGREGATE_##name_;
-
-#define MPIR_T_PVAR_UINT_AGGREGATE_DECL_EXTERN_impl(name_) \
-    extern unsigned PVAR_AGGREGATE_##name_;
-#define MPIR_T_PVAR_ULONG_AGGREGATE_DECL_EXTERN_impl(name_) \
-    extern unsigned long PVAR_AGGREGATE_##name_;
-#define MPIR_T_PVAR_ULONG2_AGGREGATE_DECL_EXTERN_impl(name_) \
-    extern unsigned long long PVAR_AGGREGATE_##name_;
-#define MPIR_T_PVAR_DOUBLE_AGGREGATE_DECL_EXTERN_impl(name_) \
-    extern double PVAR_AGGREGATE_##name_;
-
 /* Interfaces through pointer or name */
 #define MPIR_T_PVAR_AGGREGATE_INIT_VAR_impl(ptr_) \
     do { *(ptr_) = 0; } while (0)
@@ -820,10 +669,10 @@ extern void MPIR_T_PVAR_REGISTER_impl(
     do { \
         void *addr; \
         /* Allowable datatypes only */ \
-        MPIU_Assert((dtype_) == MPI_UNSIGNED || (dtype_) == MPI_UNSIGNED_LONG || \
+        MPIR_Assert((dtype_) == MPI_UNSIGNED || (dtype_) == MPI_UNSIGNED_LONG || \
                     (dtype_) == MPI_UNSIGNED_LONG_LONG || (dtype_) == MPI_DOUBLE); \
         /* Double check if dtype_ and name_ match*/ \
-        MPIU_Assert(sizeof(PVAR_AGGREGATE_##name_) == MPID_Datatype_get_basic_size(dtype_)); \
+        MPIR_Assert(sizeof(PVAR_AGGREGATE_##name_) == MPIR_Datatype_get_basic_size(dtype_)); \
         PVAR_AGGREGATE_##name_ = 0; \
         addr_ = &PVAR_AGGREGATE_##name_; \
         MPIR_T_PVAR_REGISTER_impl(MPI_T_PVAR_CLASS_AGGREGATE, dtype_, #name_, \
@@ -835,9 +684,9 @@ extern void MPIR_T_PVAR_REGISTER_impl(
             addr_, count_, verb_, bind_, flags_, get_value_, get_count_, cat_, desc_) \
     do { \
         /* Allowable datatypes */ \
-        MPIU_Assert((dtype_) == MPI_UNSIGNED || (dtype_) == MPI_UNSIGNED_LONG || \
+        MPIR_Assert((dtype_) == MPI_UNSIGNED || (dtype_) == MPI_UNSIGNED_LONG || \
                     (dtype_) == MPI_UNSIGNED_LONG_LONG || (dtype_) == MPI_DOUBLE); \
-        MPIU_Assert((addr_) != NULL || (get_value_) != NULL); \
+        MPIR_Assert((addr_) != NULL || (get_value_) != NULL); \
         MPIR_T_PVAR_REGISTER_impl(MPI_T_PVAR_CLASS_AGGREGATE, dtype_, #name_, \
             addr_, count_, MPI_T_ENUM_NULL, verb_, bind_, flags_, get_value_, \
             get_count_, cat_, desc_); \
@@ -847,16 +696,6 @@ extern void MPIR_T_PVAR_REGISTER_impl(
 /* MPI_T_PVAR_CLASS_TIMER (continuous or not)
  */
 
-/* Declaration -- static timer */
-#define MPIR_T_PVAR_DOUBLE_TIMER_DECL_impl(name_) \
-    MPIR_T_pvar_timer_t PVAR_TIMER_##name_;
-
-#define MPIR_T_PVAR_DOUBLE_TIMER_DECL_STATIC_impl(name_) \
-    static MPIR_T_pvar_timer_t PVAR_TIMER_##name_;
-
-#define MPIR_T_PVAR_DOUBLE_TIMER_DECL_EXTERN_impl(name_) \
-    extern MPIR_T_pvar_timer_t PVAR_TIMER_##name_;
-
 /* Interfaces through pointer or name */
 #define MPIR_T_PVAR_TIMER_INIT_VAR_impl(ptr_) \
     do { \
@@ -874,9 +713,9 @@ extern void MPIR_T_PVAR_REGISTER_impl(
     } while (0)
 #define MPIR_T_PVAR_TIMER_END_VAR_impl(ptr_) \
     do { \
-        MPID_Time_t tmp; \
-        MPID_Wtime(&tmp); \
-        MPID_Wtime_acc(&((ptr_)->curstart), &tmp, &((ptr_)->total)); \
+        MPID_Time_t tmp_; \
+        MPID_Wtime(&tmp_); \
+        MPID_Wtime_acc(&((ptr_)->curstart), &tmp_, &((ptr_)->total)); \
     } while (0)
 
 #define MPIR_T_PVAR_TIMER_INIT_impl(name_) \
@@ -892,8 +731,8 @@ extern void MPIR_T_PVAR_REGISTER_impl(
 
 /* Customized get_value() for MPIR_T_pvar_timer_t */
 static inline
-void get_timer_time_in_double(MPIR_T_pvar_timer_t *timer, void *obj_handle,
-                    int count, double *buf)
+    void get_timer_time_in_double(MPIR_T_pvar_timer_t * timer, void *obj_handle,
+                                  int count, double *buf)
 {
     int i;
     for (i = 0; i < count; i++)
@@ -907,7 +746,7 @@ void get_timer_time_in_double(MPIR_T_pvar_timer_t *timer, void *obj_handle,
         void *addr_; \
         void *count_addr_; \
         /* Allowable datatypes only */ \
-        MPIU_Assert((dtype_) == MPI_DOUBLE); \
+        MPIR_Assert((dtype_) == MPI_DOUBLE); \
         MPIR_T_PVAR_TIMER_INIT_impl(name_); \
         addr_ = &PVAR_TIMER_##name_; \
         count_addr_ = &(PVAR_TIMER_##name_.count); \
@@ -923,34 +762,6 @@ void get_timer_time_in_double(MPIR_T_pvar_timer_t *timer, void *obj_handle,
 /* MPI_T_PVAR_CLASS_HIGHWATERMARK (continuous or not)
  */
 
-/* Declaration -- static pvar */
-#define MPIR_T_PVAR_UINT_HIGHWATERMARK_DECL_impl(name_) \
-    MPIR_T_pvar_watermark_t PVAR_HIGHWATERMARK_##name_;
-#define MPIR_T_PVAR_ULONG_HIGHWATERMARK_DECL_impl(name_) \
-    MPIR_T_pvar_watermark_t PVAR_HIGHWATERMARK_##name_;
-#define MPIR_T_PVAR_ULONG2_HIGHWATERMARK_DECL_impl(name_) \
-    MPIR_T_pvar_watermark_t PVAR_HIGHWATERMARK_##name_;
-#define MPIR_T_PVAR_DOUBLE_HIGHWATERMARK_DECL_impl(name_) \
-    MPIR_T_pvar_watermark_t PVAR_HIGHWATERMARK_##name_;
-
-#define MPIR_T_PVAR_UINT_HIGHWATERMARK_DECL_STATIC_impl(name_) \
-    static MPIR_T_pvar_watermark_t PVAR_HIGHWATERMARK_##name_;
-#define MPIR_T_PVAR_ULONG_HIGHWATERMARK_DECL_STATIC_impl(name_) \
-    static MPIR_T_pvar_watermark_t PVAR_HIGHWATERMARK_##name_;
-#define MPIR_T_PVAR_ULONG2_HIGHWATERMARK_DECL_STATIC_impl(name_) \
-    static MPIR_T_pvar_watermark_t PVAR_HIGHWATERMARK_##name_;
-#define MPIR_T_PVAR_DOUBLE_HIGHWATERMARK_DECL_STATIC_impl(name_) \
-    static MPIR_T_pvar_watermark_t PVAR_HIGHWATERMARK_##name_;
-
-#define MPIR_T_PVAR_UINT_HIGHWATERMARK_DECL_EXTERN_impl(name_) \
-    extern MPIR_T_pvar_watermark_t PVAR_HIGHWATERMARK_##name_;
-#define MPIR_T_PVAR_ULONG_HIGHWATERMARK_DECL_EXTERN_impl(name_) \
-    extern MPIR_T_pvar_watermark_t PVAR_HIGHWATERMARK_##name_;
-#define MPIR_T_PVAR_ULONG2_HIGHWATERMARK_DECL_EXTERN_impl(name_) \
-    extern MPIR_T_pvar_watermark_t PVAR_HIGHWATERMARK_##name_;
-#define MPIR_T_PVAR_DOUBLE_HIGHWATERMARK_DECL_EXTERN_impl(name_) \
-    extern MPIR_T_pvar_watermark_t PVAR_HIGHWATERMARK_##name_;
-
 /* Interfaces through pointer or name.
  * In contrast to previous pvar classes, for each type we create a set
  * of interfaces. That is because we have a pointer and a union in the
@@ -1084,7 +895,7 @@ void get_timer_time_in_double(MPIR_T_pvar_timer_t *timer, void *obj_handle,
     do { \
         void *addr_; \
         /* Allowable datatypes only */ \
-        MPIU_Assert((dtype_) == MPI_UNSIGNED || (dtype_) == MPI_UNSIGNED_LONG || \
+        MPIR_Assert((dtype_) == MPI_UNSIGNED || (dtype_) == MPI_UNSIGNED_LONG || \
                     (dtype_) == MPI_UNSIGNED_LONG_LONG || (dtype_) == MPI_DOUBLE); \
         switch (dtype_) { \
         case MPI_UNSIGNED: \
@@ -1108,9 +919,9 @@ void get_timer_time_in_double(MPIR_T_pvar_timer_t *timer, void *obj_handle,
             addr_, count_, verb_, bind_, flags_, get_value_, get_count_, cat_, desc_) \
     do { \
         /* Allowable datatypes */ \
-        MPIU_Assert((dtype_) == MPI_UNSIGNED || (dtype_) == MPI_UNSIGNED_LONG || \
+        MPIR_Assert((dtype_) == MPI_UNSIGNED || (dtype_) == MPI_UNSIGNED_LONG || \
                     (dtype_) == MPI_UNSIGNED_LONG_LONG || (dtype_) == MPI_DOUBLE); \
-        MPIU_Assert((addr_) != NULL || (get_value_) != NULL); \
+        MPIR_Assert((addr_) != NULL || (get_value_) != NULL); \
         MPIR_T_PVAR_REGISTER_impl(MPI_T_PVAR_CLASS_HIGHWATERMARK, dtype_, #name_, \
             addr_, count_, MPI_T_ENUM_NULL, verb_, bind_, flags_, get_value_, \
             get_count_, cat_, desc_); \
@@ -1120,34 +931,6 @@ void get_timer_time_in_double(MPIR_T_pvar_timer_t *timer, void *obj_handle,
 /* MPI_T_PVAR_CLASS_LOWWATERMARK (continuous or not)
  */
 
-/* Declaration -- static pvar */
-#define MPIR_T_PVAR_UINT_LOWWATERMARK_DECL_impl(name_) \
-    MPIR_T_pvar_watermark_t PVAR_LOWWATERMARK_##name_;
-#define MPIR_T_PVAR_ULONG_LOWWATERMARK_DECL_impl(name_) \
-    MPIR_T_pvar_watermark_t PVAR_LOWWATERMARK_##name_;
-#define MPIR_T_PVAR_ULONG2_LOWWATERMARK_DECL_impl(name_) \
-    MPIR_T_pvar_watermark_t PVAR_LOWWATERMARK_##name_;
-#define MPIR_T_PVAR_DOUBLE_LOWWATERMARK_DECL_impl(name_) \
-    MPIR_T_pvar_watermark_t PVAR_LOWWATERMARK_##name_;
-
-#define MPIR_T_PVAR_UINT_LOWWATERMARK_DECL_STATIC_impl(name_) \
-    static MPIR_T_pvar_watermark_t PVAR_LOWWATERMARK_##name_;
-#define MPIR_T_PVAR_ULONG_LOWWATERMARK_DECL_STATIC_impl(name_) \
-    static MPIR_T_pvar_watermark_t PVAR_LOWWATERMARK_##name_;
-#define MPIR_T_PVAR_ULONG2_LOWWATERMARK_DECL_STATIC_impl(name_) \
-    static MPIR_T_pvar_watermark_t PVAR_LOWWATERMARK_##name_;
-#define MPIR_T_PVAR_DOUBLE_LOWWATERMARK_DECL_STATIC_impl(name_) \
-    static MPIR_T_pvar_watermark_t PVAR_LOWWATERMARK_##name_;
-
-#define MPIR_T_PVAR_UINT_LOWWATERMARK_DECL_EXTERN_impl(name_) \
-    extern MPIR_T_pvar_watermark_t PVAR_LOWWATERMARK_##name_;
-#define MPIR_T_PVAR_ULONG_LOWWATERMARK_DECL_EXTERN_impl(name_) \
-    extern MPIR_T_pvar_watermark_t PVAR_LOWWATERMARK_##name_;
-#define MPIR_T_PVAR_ULONG2_LOWWATERMARK_DECL_EXTERN_impl(name_) \
-    extern MPIR_T_pvar_watermark_t PVAR_LOWWATERMARK_##name_;
-#define MPIR_T_PVAR_DOUBLE_LOWWATERMARK_DECL_EXTERN_impl(name_) \
-    extern MPIR_T_pvar_watermark_t PVAR_LOWWATERMARK_##name_;
-
 #define MPIR_T_PVAR_UINT_LOWWATERMARK_INIT_VAR_impl(ptr_, val_) \
     do { \
         (ptr_)->datatype = MPI_UNSIGNED; \
@@ -1277,7 +1060,7 @@ void get_timer_time_in_double(MPIR_T_pvar_timer_t *timer, void *obj_handle,
     do { \
         void *addr_; \
         /* Allowable datatypes only */ \
-        MPIU_Assert((dtype_) == MPI_UNSIGNED || (dtype_) == MPI_UNSIGNED_LONG || \
+        MPIR_Assert((dtype_) == MPI_UNSIGNED || (dtype_) == MPI_UNSIGNED_LONG || \
                     (dtype_) == MPI_UNSIGNED_LONG_LONG || (dtype_) == MPI_DOUBLE); \
         switch (dtype_) { \
         case MPI_UNSIGNED: \
@@ -1301,9 +1084,9 @@ void get_timer_time_in_double(MPIR_T_pvar_timer_t *timer, void *obj_handle,
             addr_, count_, verb_, bind_, flags_, get_value_, get_count_, cat_, desc_) \
     do { \
         /* Allowable datatypes */ \
-        MPIU_Assert((dtype_) == MPI_UNSIGNED || (dtype_) == MPI_UNSIGNED_LONG || \
+        MPIR_Assert((dtype_) == MPI_UNSIGNED || (dtype_) == MPI_UNSIGNED_LONG || \
                     (dtype_) == MPI_UNSIGNED_LONG_LONG || (dtype_) == MPI_DOUBLE); \
-        MPIU_Assert((addr_) != NULL || (get_value_) != NULL); \
+        MPIR_Assert((addr_) != NULL || (get_value_) != NULL); \
         MPIR_T_PVAR_REGISTER_impl(MPI_T_PVAR_CLASS_LOWWATERMARK, dtype_, #name_, \
             addr_, count_, MPI_T_ENUM_NULL, verb_, bind_, flags_, get_value_, \
             get_count_, cat_, desc_); \
@@ -1317,67 +1100,81 @@ void get_timer_time_in_double(MPIR_T_pvar_timer_t *timer, void *obj_handle,
                 (pvar_table_entry_t *)utarray_eltptr(pvar_table, idx_); \
             if (pvar != NULL) { \
                 pvar->active = FALSE; \
-                /* Do not do MPIU_Free(pvar->info), since it may be re-activated */ \
+                /* Do not do MPL_free(pvar->info), since it may be re-activated */ \
             } \
         } \
     } while (0)
 
-static inline int MPIR_T_pvar_is_readonly(MPIR_T_pvar_handle_t *handle) {
+static inline int MPIR_T_pvar_is_readonly(MPIR_T_pvar_handle_t * handle)
+{
     return handle->flags & MPIR_T_PVAR_FLAG_READONLY;
 }
 
-static inline int MPIR_T_pvar_is_continuous(MPIR_T_pvar_handle_t *handle) {
+static inline int MPIR_T_pvar_is_continuous(MPIR_T_pvar_handle_t * handle)
+{
     return handle->flags & MPIR_T_PVAR_FLAG_CONTINUOUS;
 }
 
-static inline int MPIR_T_pvar_is_atomic(MPIR_T_pvar_handle_t *handle) {
+static inline int MPIR_T_pvar_is_atomic(MPIR_T_pvar_handle_t * handle)
+{
     return handle->flags & MPIR_T_PVAR_FLAG_ATOMIC;
 }
 
-static inline int MPIR_T_pvar_is_sum(MPIR_T_pvar_handle_t *handle) {
+static inline int MPIR_T_pvar_is_sum(MPIR_T_pvar_handle_t * handle)
+{
     return handle->flags & MPIR_T_PVAR_FLAG_SUM;
 }
 
-static inline int MPIR_T_pvar_is_watermark(MPIR_T_pvar_handle_t *handle) {
+static inline int MPIR_T_pvar_is_watermark(MPIR_T_pvar_handle_t * handle)
+{
     return handle->flags & MPIR_T_PVAR_FLAG_WATERMARK;
 }
 
-static inline int MPIR_T_pvar_is_started(MPIR_T_pvar_handle_t *handle) {
+static inline int MPIR_T_pvar_is_started(MPIR_T_pvar_handle_t * handle)
+{
     return handle->flags & MPIR_T_PVAR_FLAG_STARTED;
 }
 
-static inline void MPIR_T_pvar_set_started(MPIR_T_pvar_handle_t *handle) {
+static inline void MPIR_T_pvar_set_started(MPIR_T_pvar_handle_t * handle)
+{
     handle->flags |= (MPIR_T_PVAR_FLAG_STARTED | MPIR_T_PVAR_FLAG_ONCESTARTED);
 }
 
-static inline void MPIR_T_pvar_unset_started(MPIR_T_pvar_handle_t *handle) {
+static inline void MPIR_T_pvar_unset_started(MPIR_T_pvar_handle_t * handle)
+{
     handle->flags &= ~MPIR_T_PVAR_FLAG_STARTED;
 }
 
-static inline int MPIR_T_pvar_is_oncestarted(MPIR_T_pvar_handle_t *handle) {
+static inline int MPIR_T_pvar_is_oncestarted(MPIR_T_pvar_handle_t * handle)
+{
     return handle->flags & MPIR_T_PVAR_FLAG_ONCESTARTED;
 }
 
-static inline void MPIR_T_pvar_unset_oncestarted(MPIR_T_pvar_handle_t *handle) {
+static inline void MPIR_T_pvar_unset_oncestarted(MPIR_T_pvar_handle_t * handle)
+{
     handle->flags &= ~MPIR_T_PVAR_FLAG_ONCESTARTED;
 }
 
-static inline int MPIR_T_pvar_is_first(MPIR_T_pvar_handle_t *handle) {
+static inline int MPIR_T_pvar_is_first(MPIR_T_pvar_handle_t * handle)
+{
     return handle->flags & MPIR_T_PVAR_FLAG_FIRST;
 }
 
-static inline int MPIR_T_pvar_set_first(MPIR_T_pvar_handle_t *handle) {
+static inline int MPIR_T_pvar_set_first(MPIR_T_pvar_handle_t * handle)
+{
     return handle->flags |= MPIR_T_PVAR_FLAG_FIRST;
 }
 
-static inline int MPIR_T_pvar_unset_first(MPIR_T_pvar_handle_t *handle) {
+static inline int MPIR_T_pvar_unset_first(MPIR_T_pvar_handle_t * handle)
+{
     return handle->flags &= ~MPIR_T_PVAR_FLAG_FIRST;
 }
 
 /* A counter that keeps track of the relative balance of calls to
  * MPI_T_init_thread and MPI_T_finalize */
 extern int MPIR_T_init_balance;
-static inline int MPIR_T_is_initialized() {
+static inline int MPIR_T_is_initialized()
+{
     return MPIR_T_init_balance > 0;
 }
 
@@ -1390,13 +1187,13 @@ extern int MPIR_T_is_threaded;
 #define MPIR_T_THREAD_CHECK_END }
 
 #ifdef MPICH_IS_THREADED
-extern MPIU_Thread_mutex_t mpi_t_mutex;
+extern MPID_Thread_mutex_t mpi_t_mutex;
 #define MPIR_T_THREAD_CS_INIT() \
     do { \
         int err_; \
         MPIR_T_THREAD_CHECK_BEGIN \
         MPID_Thread_mutex_create(&mpi_t_mutex, &err_); \
-        MPIU_Assert(err_ == 0); \
+        MPIR_Assert(err_ == 0); \
         MPIR_T_THREAD_CHECK_END \
     } while (0)
 
@@ -1405,7 +1202,7 @@ extern MPIU_Thread_mutex_t mpi_t_mutex;
         int err_; \
         MPIR_T_THREAD_CHECK_BEGIN \
         MPID_Thread_mutex_destroy(&mpi_t_mutex, &err_); \
-        MPIU_Assert(err_ == 0); \
+        MPIR_Assert(err_ == 0); \
         MPIR_T_THREAD_CHECK_END \
     } while (0)
 
@@ -1435,4 +1232,4 @@ extern MPIU_Thread_mutex_t mpi_t_mutex;
 extern void MPIR_T_env_init(void);
 extern void MPIR_T_env_finalize(void);
 
-#endif
+#endif /* MPITIMPL_H_INCLUDED */
