@@ -15,7 +15,8 @@
 #elif defined(HAVE_PRAGMA_CRI_DUP)
 #pragma _CRI duplicate MPI_Win_set_name as PMPI_Win_set_name
 #elif defined(HAVE_WEAK_ATTRIBUTE)
-int MPI_Win_set_name(MPI_Win win, const char *win_name) __attribute__((weak,alias("PMPI_Win_set_name")));
+int MPI_Win_set_name(MPI_Win win, const char *win_name)
+    __attribute__ ((weak, alias("PMPI_Win_set_name")));
 #endif
 /* -- End Profiling Symbol Block */
 
@@ -29,13 +30,14 @@ int MPI_Win_set_name(MPI_Win win, const char *win_name) __attribute__((weak,alia
 
 #undef FUNCNAME
 #define FUNCNAME MPI_Win_set_name
-
+#undef FCNAME
+#define FCNAME MPL_QUOTE(FUNCNAME)
 /*@
    MPI_Win_set_name - Set the print name for an MPI RMA window
 
 Input Parameters:
-+ win - window whose identifier is to be set (handle) 
-- win_name - the character string which is remembered as the name (string) 
++ win - window whose identifier is to be set (handle)
+- win_name - the character string which is remembered as the name (string)
 
 .N ThreadSafe
 
@@ -49,67 +51,67 @@ Input Parameters:
 @*/
 int MPI_Win_set_name(MPI_Win win, const char *win_name)
 {
-    static const char FCNAME[] = "MPI_Win_set_name";
     int mpi_errno = MPI_SUCCESS;
-    MPID_Win *win_ptr = NULL;
-    MPID_MPI_STATE_DECL(MPID_STATE_MPI_WIN_SET_NAME);
+    MPIR_Win *win_ptr = NULL;
+    MPIR_FUNC_TERSE_STATE_DECL(MPID_STATE_MPI_WIN_SET_NAME);
 
     MPIR_ERRTEST_INITIALIZED_ORDIE();
-    
-    MPID_MPI_FUNC_ENTER(MPID_STATE_MPI_WIN_SET_NAME);
+
+    MPIR_FUNC_TERSE_ENTER(MPID_STATE_MPI_WIN_SET_NAME);
 
     /* Validate parameters, especially handles needing to be converted */
-#   ifdef HAVE_ERROR_CHECKING
+#ifdef HAVE_ERROR_CHECKING
     {
         MPID_BEGIN_ERROR_CHECKS;
         {
-	    MPIR_ERRTEST_WIN(win, mpi_errno);
+            MPIR_ERRTEST_WIN(win, mpi_errno);
         }
         MPID_END_ERROR_CHECKS;
     }
-#   endif
-    
+#endif
+
     /* Convert MPI object handles to object pointers */
-    MPID_Win_get_ptr( win, win_ptr );
+    MPIR_Win_get_ptr(win, win_ptr);
 
     /* Validate parameters and objects (post conversion) */
-#   ifdef HAVE_ERROR_CHECKING
+#ifdef HAVE_ERROR_CHECKING
     {
         MPID_BEGIN_ERROR_CHECKS;
         {
             /* Validate win_ptr */
-            MPID_Win_valid_ptr( win_ptr, mpi_errno );
-            if (mpi_errno) goto fn_fail;
-	    /* If win_ptr is not valid, it will be reset to null */
+            MPIR_Win_valid_ptr(win_ptr, mpi_errno);
+            if (mpi_errno)
+                goto fn_fail;
+            /* If win_ptr is not valid, it will be reset to null */
 
-	    MPIR_ERRTEST_ARGNULL(win_name, "win_name", mpi_errno);
+            MPIR_ERRTEST_ARGNULL(win_name, "win_name", mpi_errno);
         }
         MPID_END_ERROR_CHECKS;
     }
-#   endif /* HAVE_ERROR_CHECKING */
+#endif /* HAVE_ERROR_CHECKING */
 
     /* ... body of routine ...  */
-    
-    MPIU_Strncpy( win_ptr->name, win_name, MPI_MAX_OBJECT_NAME );
-    
+
+    MPL_strncpy(win_ptr->name, win_name, MPI_MAX_OBJECT_NAME);
+
     /* ... end of body of routine ... */
 
+#ifdef HAVE_ERROR_CHECKING
   fn_exit:
-    MPID_MPI_FUNC_EXIT(MPID_STATE_MPI_WIN_SET_NAME);
+#endif
+    MPIR_FUNC_TERSE_EXIT(MPID_STATE_MPI_WIN_SET_NAME);
     return mpi_errno;
 
+#ifdef HAVE_ERROR_CHECKING
   fn_fail:
     /* --BEGIN ERROR HANDLING-- */
-#   ifdef HAVE_ERROR_CHECKING
     {
-	mpi_errno = MPIR_Err_create_code(
-	    mpi_errno, MPIR_ERR_RECOVERABLE, FCNAME, __LINE__, MPI_ERR_OTHER,
-	    "**mpi_win_set_name", 
-	    "**mpi_win_set_name %W %s", win, win_name);
+        mpi_errno =
+            MPIR_Err_create_code(mpi_errno, MPIR_ERR_RECOVERABLE, FCNAME, __LINE__, MPI_ERR_OTHER,
+                                 "**mpi_win_set_name", "**mpi_win_set_name %W %s", win, win_name);
     }
-#   endif
-    mpi_errno = MPIR_Err_return_win( win_ptr, FCNAME, mpi_errno );
+    mpi_errno = MPIR_Err_return_win(win_ptr, FCNAME, mpi_errno);
     goto fn_exit;
     /* --END ERROR HANDLING-- */
+#endif
 }
-
