@@ -15,7 +15,7 @@
 #elif defined(HAVE_PRAGMA_CRI_DUP)
 #pragma _CRI duplicate MPI_Win_unlock as PMPI_Win_unlock
 #elif defined(HAVE_WEAK_ATTRIBUTE)
-int MPI_Win_unlock(int rank, MPI_Win win) __attribute__((weak,alias("PMPI_Win_unlock")));
+int MPI_Win_unlock(int rank, MPI_Win win) __attribute__ ((weak, alias("PMPI_Win_unlock")));
 #endif
 /* -- End Profiling Symbol Block */
 
@@ -29,13 +29,14 @@ int MPI_Win_unlock(int rank, MPI_Win win) __attribute__((weak,alias("PMPI_Win_un
 
 #undef FUNCNAME
 #define FUNCNAME MPI_Win_unlock
-
+#undef FCNAME
+#define FCNAME MPL_QUOTE(FUNCNAME)
 /*@
    MPI_Win_unlock - Completes an RMA access epoch at the target process
 
 Input Parameters:
-+ rank - rank of window (nonnegative integer) 
-- win - window object (handle) 
++ rank - rank of window (nonnegative integer)
+- win - window object (handle)
 
 .N ThreadSafe
 
@@ -51,74 +52,74 @@ Input Parameters:
 @*/
 int MPI_Win_unlock(int rank, MPI_Win win)
 {
-    static const char FCNAME[] = "MPI_Win_unlock";
     int mpi_errno = MPI_SUCCESS;
-    MPID_Win *win_ptr = NULL;
-    MPID_MPI_STATE_DECL(MPID_STATE_MPI_WIN_UNLOCK);
+    MPIR_Win *win_ptr = NULL;
+    MPIR_FUNC_TERSE_STATE_DECL(MPID_STATE_MPI_WIN_UNLOCK);
 
     MPIR_ERRTEST_INITIALIZED_ORDIE();
-    
+
     MPID_THREAD_CS_ENTER(GLOBAL, MPIR_THREAD_GLOBAL_ALLFUNC_MUTEX);
-    MPID_MPI_FUNC_ENTER(MPID_STATE_MPI_WIN_UNLOCK);
+    MPIR_FUNC_TERSE_ENTER(MPID_STATE_MPI_WIN_UNLOCK);
 
     /* Validate parameters, especially handles needing to be converted */
-#   ifdef HAVE_ERROR_CHECKING
+#ifdef HAVE_ERROR_CHECKING
     {
         MPID_BEGIN_ERROR_CHECKS;
         {
-	    MPIR_ERRTEST_WIN(win, mpi_errno);
+            MPIR_ERRTEST_WIN(win, mpi_errno);
         }
         MPID_END_ERROR_CHECKS;
     }
-#   endif /* HAVE_ERROR_CHECKING */
-    
+#endif /* HAVE_ERROR_CHECKING */
+
     /* Convert MPI object handles to object pointers */
-    MPID_Win_get_ptr( win, win_ptr );
+    MPIR_Win_get_ptr(win, win_ptr);
 
     /* Validate parameters and objects (post conversion) */
-#   ifdef HAVE_ERROR_CHECKING
+#ifdef HAVE_ERROR_CHECKING
     {
         MPID_BEGIN_ERROR_CHECKS;
         {
-	    MPID_Comm * comm_ptr;
-	    
-            /* Validate win_ptr */
-            MPID_Win_valid_ptr( win_ptr, mpi_errno );
-	    /* If win_ptr is not valid, it will be reset to null */
-            if (mpi_errno) goto fn_fail;
+            MPIR_Comm *comm_ptr;
 
-	    comm_ptr = win_ptr->comm_ptr;
+            /* Validate win_ptr */
+            MPIR_Win_valid_ptr(win_ptr, mpi_errno);
+            /* If win_ptr is not valid, it will be reset to null */
+            if (mpi_errno)
+                goto fn_fail;
+
+            comm_ptr = win_ptr->comm_ptr;
             MPIR_ERRTEST_SEND_RANK(comm_ptr, rank, mpi_errno);
 
             /* TODO: Test that the rank we are unlocking is a rank that we locked */
         }
         MPID_END_ERROR_CHECKS;
     }
-#   endif /* HAVE_ERROR_CHECKING */
+#endif /* HAVE_ERROR_CHECKING */
 
     /* ... body of routine ...  */
-    
+
     mpi_errno = MPID_Win_unlock(rank, win_ptr);
-    if (mpi_errno != MPI_SUCCESS) goto fn_fail;
+    if (mpi_errno != MPI_SUCCESS)
+        goto fn_fail;
 
     /* ... end of body of routine ... */
 
   fn_exit:
-    MPID_MPI_FUNC_EXIT(MPID_STATE_MPI_WIN_UNLOCK);
+    MPIR_FUNC_TERSE_EXIT(MPID_STATE_MPI_WIN_UNLOCK);
     MPID_THREAD_CS_EXIT(GLOBAL, MPIR_THREAD_GLOBAL_ALLFUNC_MUTEX);
     return mpi_errno;
 
   fn_fail:
     /* --BEGIN ERROR HANDLING-- */
-#   ifdef HAVE_ERROR_CHECKING
+#ifdef HAVE_ERROR_CHECKING
     {
-	mpi_errno = MPIR_Err_create_code(
-	    mpi_errno, MPIR_ERR_RECOVERABLE, FCNAME, __LINE__, MPI_ERR_OTHER, "**mpi_win_unlock", 
-	    "**mpi_win_unlock %d %W", rank, win);
+        mpi_errno =
+            MPIR_Err_create_code(mpi_errno, MPIR_ERR_RECOVERABLE, FCNAME, __LINE__, MPI_ERR_OTHER,
+                                 "**mpi_win_unlock", "**mpi_win_unlock %d %W", rank, win);
     }
-#   endif
-    mpi_errno = MPIR_Err_return_win( win_ptr, FCNAME, mpi_errno );
+#endif
+    mpi_errno = MPIR_Err_return_win(win_ptr, FCNAME, mpi_errno);
     goto fn_exit;
     /* --END ERROR HANDLING-- */
 }
-
