@@ -11,8 +11,8 @@
 #undef FCNAME
 #define FCNAME MPL_QUOTE(FUNCNAME)
 int MPID_Recv(void * buf, MPI_Aint count, MPI_Datatype datatype, int rank, int tag,
-	      MPID_Comm * comm, int context_offset,
-	      MPI_Status * status, MPID_Request ** request)
+	      MPIR_Comm * comm, int context_offset,
+	      MPI_Status * status, MPIR_Request ** request)
 {
     /* FIXME: in the common case, we want to simply complete the message
        and make as few updates as possible.
@@ -22,13 +22,13 @@ int MPID_Recv(void * buf, MPI_Aint count, MPI_Datatype datatype, int rank, int t
        message was not found in the unexpected queue. */
 
     int mpi_errno = MPI_SUCCESS;
-    MPID_Request * rreq;
+    MPIR_Request * rreq;
     int found;
-    MPIDI_STATE_DECL(MPID_STATE_MPID_RECV);
+    MPIR_FUNC_VERBOSE_STATE_DECL(MPID_STATE_MPID_RECV);
 
-    MPIDI_FUNC_ENTER(MPID_STATE_MPID_RECV);
+    MPIR_FUNC_VERBOSE_ENTER(MPID_STATE_MPID_RECV);
 
-    MPIU_DBG_MSG_FMT(CH3_OTHER,VERBOSE,(MPIU_DBG_FDEST,
+    MPL_DBG_MSG_FMT(MPIDI_CH3_DBG_OTHER,VERBOSE,(MPL_DBG_FDEST,
                       "rank=%d, tag=%d, context=%d", rank, tag,
 		      comm->recvcontext_id + context_offset));
     
@@ -41,8 +41,8 @@ int MPID_Recv(void * buf, MPI_Aint count, MPI_Datatype datatype, int rank, int t
 
     /* Check to make sure the communicator hasn't already been revoked */
     if (comm->revoked &&
-            MPIR_AGREE_TAG != MPIR_TAG_MASK_ERROR_BITS(tag & ~MPIR_Process.tagged_coll_mask) &&
-            MPIR_SHRINK_TAG != MPIR_TAG_MASK_ERROR_BITS(tag & ~MPIR_Process.tagged_coll_mask)) {
+            MPIR_AGREE_TAG != MPIR_TAG_MASK_ERROR_BITS(tag & ~MPIR_TAG_COLL_BIT) &&
+            MPIR_SHRINK_TAG != MPIR_TAG_MASK_ERROR_BITS(tag & ~MPIR_TAG_COLL_BIT)) {
         MPIR_ERR_SETANDJUMP(mpi_errno,MPIX_ERR_REVOKED,"**revoked");
     }
 
@@ -60,7 +60,7 @@ int MPID_Recv(void * buf, MPI_Aint count, MPI_Datatype datatype, int rank, int t
 	MPIDI_VC_t * vc;
 
 	/* Message was found in the unexepected queue */
-	MPIU_DBG_MSG(CH3_OTHER,VERBOSE,"request found in unexpected queue");
+	MPL_DBG_MSG(MPIDI_CH3_DBG_OTHER,VERBOSE,"request found in unexpected queue");
 
 	/* Release the message queue - we've removed this request from 
 	   the queue already */
@@ -70,7 +70,7 @@ int MPID_Recv(void * buf, MPI_Aint count, MPI_Datatype datatype, int rank, int t
 	    int recv_pending;
 	    
 	    /* This is an eager message. */
-	    MPIU_DBG_MSG(CH3_OTHER,VERBOSE,"eager message in the request");
+	    MPL_DBG_MSG(MPIDI_CH3_DBG_OTHER,VERBOSE,"eager message in the request");
 
 	    if (MPIDI_Request_get_sync_send_flag(rreq))
 	    {
@@ -85,16 +85,16 @@ int MPID_Recv(void * buf, MPI_Aint count, MPI_Datatype datatype, int rank, int t
             MPIDI_Request_decr_pending(rreq);
             MPIDI_Request_check_pending(rreq, &recv_pending);
 
-            if (MPID_Request_is_complete(rreq)) {
+            if (MPIR_Request_is_complete(rreq)) {
                 /* is it ever possible to have (cc==0 && recv_pending>0) ? */
-                MPIU_Assert(!recv_pending);
+                MPIR_Assert(!recv_pending);
 
                 /* All of the data has arrived, we need to unpack the data and 
                    then free the buffer and the request. */
                 if (rreq->dev.recv_data_sz > 0)
                 {
                     MPIDI_CH3U_Request_unpack_uebuf(rreq);
-                    MPIU_Free(rreq->dev.tmpbuf);
+                    MPL_free(rreq->dev.tmpbuf);
                 }
 
                 mpi_errno = rreq->status.MPI_ERROR;
@@ -103,7 +103,7 @@ int MPID_Recv(void * buf, MPI_Aint count, MPI_Datatype datatype, int rank, int t
                     *status = rreq->status;
                 }
 
-                MPID_Request_release(rreq);
+                MPIR_Request_free(rreq);
                 rreq = NULL;
 
                 goto fn_exit;
@@ -112,15 +112,15 @@ int MPID_Recv(void * buf, MPI_Aint count, MPI_Datatype datatype, int rank, int t
 	    {
                 /* there should never be outstanding completion events for an unexpected
                  * recv without also having a "pending recv" */
-                MPIU_Assert(recv_pending);
+                MPIR_Assert(recv_pending);
 
 		/* The data is still being transfered across the net.  
 		   We'll leave it to the progress engine to handle once the
 		   entire message has arrived. */
 		if (HANDLE_GET_KIND(datatype) != HANDLE_KIND_BUILTIN)
 		{
-		    MPID_Datatype_get_ptr(datatype, rreq->dev.datatype_ptr);
-		    MPID_Datatype_add_ref(rreq->dev.datatype_ptr);
+		    MPIR_Datatype_get_ptr(datatype, rreq->dev.datatype_ptr);
+            MPIR_Datatype_ptr_add_ref(rreq->dev.datatype_ptr);
 		}
 	    }
 	}
@@ -132,8 +132,8 @@ int MPID_Recv(void * buf, MPI_Aint count, MPI_Datatype datatype, int rank, int t
 	    if (mpi_errno) MPIR_ERR_POP(mpi_errno);
 	    if (HANDLE_GET_KIND(datatype) != HANDLE_KIND_BUILTIN)
 	    {
-		MPID_Datatype_get_ptr(datatype, rreq->dev.datatype_ptr);
-		MPID_Datatype_add_ref(rreq->dev.datatype_ptr);
+		MPIR_Datatype_get_ptr(datatype, rreq->dev.datatype_ptr);
+        MPIR_Datatype_ptr_add_ref(rreq->dev.datatype_ptr);
 	    }
 	}
 	else if (MPIDI_Request_get_msg_type(rreq) == MPIDI_REQUEST_SELF_MSG)
@@ -151,7 +151,7 @@ int MPID_Recv(void * buf, MPI_Aint count, MPI_Datatype datatype, int rank, int t
 #ifdef HAVE_ERROR_CHECKING
             int msg_type = MPIDI_Request_get_msg_type(rreq);
 #endif
-            MPID_Request_release(rreq);
+            MPIR_Request_free(rreq);
 	    rreq = NULL;
 	    MPIR_ERR_SETANDJUMP1(mpi_errno,MPI_ERR_INTERN, "**ch3|badmsgtype",
                                  "**ch3|badmsgtype %d", msg_type);
@@ -163,7 +163,7 @@ int MPID_Recv(void * buf, MPI_Aint count, MPI_Datatype datatype, int rank, int t
 	/* Message has yet to arrived.  The request has been placed on the 
 	   list of posted receive requests and populated with
            information supplied in the arguments. */
-	MPIU_DBG_MSG(CH3_OTHER,VERBOSE,"request allocated in posted queue");
+	MPL_DBG_MSG(MPIDI_CH3_DBG_OTHER,VERBOSE,"request allocated in posted queue");
 
 	/* FIXME: We do not need to add a datatype reference if
 	   the request is blocking.  This is currently added because
@@ -172,8 +172,8 @@ int MPID_Recv(void * buf, MPI_Aint count, MPI_Datatype datatype, int rank, int t
 	   decremented, and are freed if the refs are zero) */
 	if (HANDLE_GET_KIND(datatype) != HANDLE_KIND_BUILTIN)
 	{
-	    MPID_Datatype_get_ptr(datatype, rreq->dev.datatype_ptr);
-	    MPID_Datatype_add_ref(rreq->dev.datatype_ptr);
+	    MPIR_Datatype_get_ptr(datatype, rreq->dev.datatype_ptr);
+        MPIR_Datatype_ptr_add_ref(rreq->dev.datatype_ptr);
 	}
 
 	rreq->dev.recv_pending_count = 1;
@@ -185,19 +185,19 @@ int MPID_Recv(void * buf, MPI_Aint count, MPI_Datatype datatype, int rank, int t
 
   fn_exit:
     *request = rreq;
-    MPIU_DBG_STMT(CH3_OTHER,VERBOSE,
+    MPL_DBG_STMT(MPIDI_CH3_DBG_OTHER,VERBOSE,
     if (rreq)
     {
-	MPIU_DBG_MSG_P(CH3_OTHER,VERBOSE,
+	MPL_DBG_MSG_P(MPIDI_CH3_DBG_OTHER,VERBOSE,
 		       "request allocated, handle=0x%08x", rreq->handle);
     }
     else
     {
-	MPIU_DBG_MSG(CH3_OTHER,VERBOSE,
+	MPL_DBG_MSG(MPIDI_CH3_DBG_OTHER,VERBOSE,
 		     "operation complete, no requests allocated");
     });
 
  fn_fail:
-    MPIDI_FUNC_EXIT(MPID_STATE_MPID_RECV);
+    MPIR_FUNC_VERBOSE_EXIT(MPID_STATE_MPID_RECV);
     return mpi_errno;
 }
