@@ -45,7 +45,6 @@ int main(int argc, char **argv)
 #endif
 
     MTest_Finalize(errs);
-    MPI_Finalize();
 
-    return 0;
+    return MTestReturnValue(errs);
 }
