@@ -1,4 +1,4 @@
-! This file created from test/mpi/f77/io/c2f2ciof.f with f77tof90
+! This file created from f77/io/c2f2ciof.f with f77tof90
 ! -*- Mode: Fortran; -*- 
 !
 !  (C) 2003 by Argonne National Laboratory.
@@ -55,7 +55,5 @@
          endif
       endif
 
-      call mpi_finalize( ierr )
-      stop
       end
       
